from typing import Any

class RTC:
    def __init__(self, *argv, **kwargs) -> None: ...
    def calibration(self, *args, **kwargs) -> Any: ...
    def datetime(self, *args, **kwargs) -> Any: ...
    def info(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def wakeup(self, *args, **kwargs) -> Any: ...

class ADC:
    def __init__(self, *argv, **kwargs) -> None: ...
    CORE_TEMP: int
    CORE_VBAT: int
    CORE_VREF: int
    VREF: int
    def read_u16(self, *args, **kwargs) -> Any: ...

DEEPSLEEP_RESET: int
HARD_RESET: int

class I2C:
    def __init__(self, *argv, **kwargs) -> None: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def start(self, *args, **kwargs) -> Any: ...
    def stop(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def readfrom(self, *args, **kwargs) -> Any: ...
    def readfrom_into(self, *args, **kwargs) -> Any: ...
    def readfrom_mem(self, *args, **kwargs) -> Any: ...
    def readfrom_mem_into(self, *args, **kwargs) -> Any: ...
    def scan(self, *args, **kwargs) -> Any: ...
    def writeto(self, *args, **kwargs) -> Any: ...
    def writeto_mem(self, *args, **kwargs) -> Any: ...
    def writevto(self, *args, **kwargs) -> Any: ...

class I2S:
    def __init__(self, *argv, **kwargs) -> None: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    MONO: int
    RX: int
    STEREO: int
    TX: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def irq(self, *args, **kwargs) -> Any: ...
    def shift(self, *args, **kwargs) -> Any: ...

PWRON_RESET: int

class Pin:
    def __init__(self, *argv, **kwargs) -> None: ...
    @classmethod
    def dict(cls, *args, **kwargs) -> Any: ...
    def value(self, *args, **kwargs) -> Any: ...
    AF1_TIM1: int
    AF1_TIM2: int
    AF2_TIM3: int
    AF2_TIM4: int
    AF2_TIM5: int
    AF3_TIM10: int
    AF3_TIM11: int
    AF3_TIM8: int
    AF3_TIM9: int
    AF4_I2C1: int
    AF4_I2C2: int
    AF5_I2S2: int
    AF5_SPI1: int
    AF5_SPI2: int
    AF6_I2S2: int
    AF7_USART1: int
    AF7_USART2: int
    AF7_USART3: int
    AF8_UART4: int
    AF8_USART6: int
    AF9_CAN1: int
    AF9_CAN2: int
    AF9_TIM12: int
    AF9_TIM13: int
    AF9_TIM14: int
    AF_OD: int
    AF_PP: int
    ALT: int
    ALT_OPEN_DRAIN: int
    ANALOG: int
    IN: int
    IRQ_FALLING: int
    IRQ_RISING: int
    OPEN_DRAIN: int
    OUT: int
    OUT_OD: int
    OUT_PP: int
    PULL_DOWN: int
    PULL_NONE: int
    PULL_UP: int
    def af(self, *args, **kwargs) -> Any: ...
    def af_list(self, *args, **kwargs) -> Any: ...

    class board:
        def __init__(self, *argv, **kwargs) -> None: ...
        LED_BLUE: Any
        LED_GREEN: Any
        LED_RED: Any
        LED_YELLOW: Any
        MMA_AVDD: Any
        MMA_INT: Any
        SD: Any
        SD_CK: Any
        SD_CMD: Any
        SD_D0: Any
        SD_D1: Any
        SD_D2: Any
        SD_D3: Any
        SD_SW: Any
        SW: Any
        USB_DM: Any
        USB_DP: Any
        USB_ID: Any
        USB_VBUS: Any
        X1: Any
        X10: Any
        X11: Any
        X12: Any
        X17: Any
        X18: Any
        X19: Any
        X2: Any
        X20: Any
        X21: Any
        X22: Any
        X3: Any
        X4: Any
        X5: Any
        X6: Any
        X7: Any
        X8: Any
        X9: Any
        Y1: Any
        Y10: Any
        Y11: Any
        Y12: Any
        Y2: Any
        Y3: Any
        Y4: Any
        Y5: Any
        Y6: Any
        Y7: Any
        Y8: Any
        Y9: Any

    class cpu:
        def __init__(self, *argv, **kwargs) -> None: ...
        A0: Any
        A1: Any
        A10: Any
        A11: Any
        A12: Any
        A13: Any
        A14: Any
        A15: Any
        A2: Any
        A3: Any
        A4: Any
        A5: Any
        A6: Any
        A7: Any
        A8: Any
        A9: Any
        B0: Any
        B1: Any
        B10: Any
        B11: Any
        B12: Any
        B13: Any
        B14: Any
        B15: Any
        B2: Any
        B3: Any
        B4: Any
        B5: Any
        B6: Any
        B7: Any
        B8: Any
        B9: Any
        C0: Any
        C1: Any
        C10: Any
        C11: Any
        C12: Any
        C13: Any
        C2: Any
        C3: Any
        C4: Any
        C5: Any
        C6: Any
        C7: Any
        C8: Any
        C9: Any
        D2: Any
    @classmethod
    def debug(cls, *args, **kwargs) -> Any: ...
    def gpio(self, *args, **kwargs) -> Any: ...
    def high(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def irq(self, *args, **kwargs) -> Any: ...
    def low(self, *args, **kwargs) -> Any: ...
    @classmethod
    def mapper(cls, *args, **kwargs) -> Any: ...
    def mode(self, *args, **kwargs) -> Any: ...
    def name(self, *args, **kwargs) -> Any: ...
    def names(self, *args, **kwargs) -> Any: ...
    def off(self, *args, **kwargs) -> Any: ...
    def on(self, *args, **kwargs) -> Any: ...
    def pin(self, *args, **kwargs) -> Any: ...
    def port(self, *args, **kwargs) -> Any: ...
    def pull(self, *args, **kwargs) -> Any: ...

SOFT_RESET: int

class SPI:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    LSB: int
    MSB: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def write_readinto(self, *args, **kwargs) -> Any: ...

class Signal:
    def __init__(self, *argv, **kwargs) -> None: ...
    def value(self, *args, **kwargs) -> Any: ...
    def off(self, *args, **kwargs) -> Any: ...
    def on(self, *args, **kwargs) -> Any: ...

class SoftI2C:
    def __init__(self, *argv, **kwargs) -> None: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def start(self, *args, **kwargs) -> Any: ...
    def stop(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def readfrom(self, *args, **kwargs) -> Any: ...
    def readfrom_into(self, *args, **kwargs) -> Any: ...
    def readfrom_mem(self, *args, **kwargs) -> Any: ...
    def readfrom_mem_into(self, *args, **kwargs) -> Any: ...
    def scan(self, *args, **kwargs) -> Any: ...
    def writeto(self, *args, **kwargs) -> Any: ...
    def writeto_mem(self, *args, **kwargs) -> Any: ...
    def writevto(self, *args, **kwargs) -> Any: ...

class SoftSPI:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    LSB: int
    MSB: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def write_readinto(self, *args, **kwargs) -> Any: ...

class Timer:
    def __init__(self, *argv, **kwargs) -> None: ...
    ONE_SHOT: int
    PERIODIC: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...

class UART:
    def __init__(self, *argv, **kwargs) -> None: ...
    def any(self, *args, **kwargs) -> Any: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readline(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    CTS: int
    IRQ_RXIDLE: int
    RTS: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def irq(self, *args, **kwargs) -> Any: ...
    def readchar(self, *args, **kwargs) -> Any: ...
    def sendbreak(self, *args, **kwargs) -> Any: ...
    def writechar(self, *args, **kwargs) -> Any: ...

class WDT:
    def __init__(self, *argv, **kwargs) -> None: ...
    def feed(self, *args, **kwargs) -> Any: ...

WDT_RESET: int

def bitstream(*args, **kwargs) -> Any: ...
def bootloader(*args, **kwargs) -> Any: ...
def deepsleep(*args, **kwargs) -> Any: ...
def disable_irq(*args, **kwargs) -> Any: ...
def enable_irq(*args, **kwargs) -> Any: ...
def freq(*args, **kwargs) -> Any: ...
def idle(*args, **kwargs) -> Any: ...
def info(*args, **kwargs) -> Any: ...
def lightsleep(*args, **kwargs) -> Any: ...

mem16: Any
mem32: Any
mem8: Any

def reset(*args, **kwargs) -> Any: ...
def reset_cause(*args, **kwargs) -> Any: ...
def rng(*args, **kwargs) -> Any: ...
def sleep(*args, **kwargs) -> Any: ...
def soft_reset(*args, **kwargs) -> Any: ...
def time_pulse_us(*args, **kwargs) -> Any: ...
def unique_id(*args, **kwargs) -> Any: ...



from typing import Any

def pow(*args, **kwargs) -> Any: ...
def acos(*args, **kwargs) -> Any: ...
def acosh(*args, **kwargs) -> Any: ...
def asin(*args, **kwargs) -> Any: ...
def asinh(*args, **kwargs) -> Any: ...
def atan(*args, **kwargs) -> Any: ...
def atan2(*args, **kwargs) -> Any: ...
def atanh(*args, **kwargs) -> Any: ...
def ceil(*args, **kwargs) -> Any: ...
def copysign(*args, **kwargs) -> Any: ...
def cos(*args, **kwargs) -> Any: ...
def cosh(*args, **kwargs) -> Any: ...
def degrees(*args, **kwargs) -> Any: ...

e: float

def erf(*args, **kwargs) -> Any: ...
def erfc(*args, **kwargs) -> Any: ...
def exp(*args, **kwargs) -> Any: ...
def expm1(*args, **kwargs) -> Any: ...
def fabs(*args, **kwargs) -> Any: ...
def factorial(*args, **kwargs) -> Any: ...
def floor(*args, **kwargs) -> Any: ...
def fmod(*args, **kwargs) -> Any: ...
def frexp(*args, **kwargs) -> Any: ...
def gamma(*args, **kwargs) -> Any: ...

inf: float

def isclose(*args, **kwargs) -> Any: ...
def isfinite(*args, **kwargs) -> Any: ...
def isinf(*args, **kwargs) -> Any: ...
def isnan(*args, **kwargs) -> Any: ...
def ldexp(*args, **kwargs) -> Any: ...
def lgamma(*args, **kwargs) -> Any: ...
def log(*args, **kwargs) -> Any: ...
def log10(*args, **kwargs) -> Any: ...
def log2(*args, **kwargs) -> Any: ...
def modf(*args, **kwargs) -> Any: ...

nan: float
pi: float

def radians(*args, **kwargs) -> Any: ...
def sin(*args, **kwargs) -> Any: ...
def sinh(*args, **kwargs) -> Any: ...
def sqrt(*args, **kwargs) -> Any: ...
def tan(*args, **kwargs) -> Any: ...
def tanh(*args, **kwargs) -> Any: ...

tau: float

def trunc(*args, **kwargs) -> Any: ...



"""
Module: 'machine' on micropython-v1.19.1-stm32
"""
# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'stm32', 'port': 'stm32', 'machine': 'PYBv1.1 with STM32F405RG', 'release': '1.19.1', 'nodename': 'pyboard', 'name': 'micropython', 'family': 'micropython', 'sysname': 'pyboard', 'version': '1.19.1'}
# Stubber: 1.5.6
from typing import Any


class RTC:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def calibration(self, *args, **kwargs) -> Any:
        ...

    def datetime(self, *args, **kwargs) -> Any:
        ...

    def info(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def wakeup(self, *args, **kwargs) -> Any:
        ...


class ADC:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    CORE_TEMP = 16  # type: int
    CORE_VBAT = 18  # type: int
    CORE_VREF = 17  # type: int
    VREF = 65535  # type: int

    def read_u16(self, *args, **kwargs) -> Any:
        ...


DEEPSLEEP_RESET = 4  # type: int
HARD_RESET = 2  # type: int


class I2C:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def readinto(self, *args, **kwargs) -> Any:
        ...

    def start(self, *args, **kwargs) -> Any:
        ...

    def stop(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def readfrom(self, *args, **kwargs) -> Any:
        ...

    def readfrom_into(self, *args, **kwargs) -> Any:
        ...

    def readfrom_mem(self, *args, **kwargs) -> Any:
        ...

    def readfrom_mem_into(self, *args, **kwargs) -> Any:
        ...

    def scan(self, *args, **kwargs) -> Any:
        ...

    def writeto(self, *args, **kwargs) -> Any:
        ...

    def writeto_mem(self, *args, **kwargs) -> Any:
        ...

    def writevto(self, *args, **kwargs) -> Any:
        ...


class I2S:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def readinto(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    MONO = 0  # type: int
    RX = 768  # type: int
    STEREO = 1  # type: int
    TX = 512  # type: int

    def deinit(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def irq(self, *args, **kwargs) -> Any:
        ...

    def shift(self, *args, **kwargs) -> Any:
        ...


PWRON_RESET = 1  # type: int


class Pin:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    @classmethod
    def dict(cls, *args, **kwargs) -> Any:
        ...

    def value(self, *args, **kwargs) -> Any:
        ...

    AF1_TIM1 = 1  # type: int
    AF1_TIM2 = 1  # type: int
    AF2_TIM3 = 2  # type: int
    AF2_TIM4 = 2  # type: int
    AF2_TIM5 = 2  # type: int
    AF3_TIM10 = 3  # type: int
    AF3_TIM11 = 3  # type: int
    AF3_TIM8 = 3  # type: int
    AF3_TIM9 = 3  # type: int
    AF4_I2C1 = 4  # type: int
    AF4_I2C2 = 4  # type: int
    AF5_I2S2 = 5  # type: int
    AF5_SPI1 = 5  # type: int
    AF5_SPI2 = 5  # type: int
    AF6_I2S2 = 6  # type: int
    AF7_USART1 = 7  # type: int
    AF7_USART2 = 7  # type: int
    AF7_USART3 = 7  # type: int
    AF8_UART4 = 8  # type: int
    AF8_USART6 = 8  # type: int
    AF9_CAN1 = 9  # type: int
    AF9_CAN2 = 9  # type: int
    AF9_TIM12 = 9  # type: int
    AF9_TIM13 = 9  # type: int
    AF9_TIM14 = 9  # type: int
    AF_OD = 18  # type: int
    AF_PP = 2  # type: int
    ALT = 2  # type: int
    ALT_OPEN_DRAIN = 18  # type: int
    ANALOG = 3  # type: int
    IN = 0  # type: int
    IRQ_FALLING = 270598144  # type: int
    IRQ_RISING = 269549568  # type: int
    OPEN_DRAIN = 17  # type: int
    OUT = 1  # type: int
    OUT_OD = 17  # type: int
    OUT_PP = 1  # type: int
    PULL_DOWN = 2  # type: int
    PULL_NONE = 0  # type: int
    PULL_UP = 1  # type: int

    def af(self, *args, **kwargs) -> Any:
        ...

    def af_list(self, *args, **kwargs) -> Any:
        ...

    class board:
        """"""

        def __init__(self, *argv, **kwargs) -> None:
            """"""
            ...

        LED_BLUE: Any  ## <class 'Pin'> = Pin(Pin.cpu.B4, mode=Pin.OUT)
        LED_GREEN: Any  ## <class 'Pin'> = Pin(Pin.cpu.A14, mode=Pin.OUT)
        LED_RED: Any  ## <class 'Pin'> = Pin(Pin.cpu.A13, mode=Pin.OUT)
        LED_YELLOW: Any  ## <class 'Pin'> = Pin(Pin.cpu.A15, mode=Pin.OUT)
        MMA_AVDD: Any  ## <class 'Pin'> = Pin(Pin.cpu.B5, mode=Pin.OUT)
        MMA_INT: Any  ## <class 'Pin'> = Pin(Pin.cpu.B2, mode=Pin.IN)
        SD: Any  ## <class 'Pin'> = Pin(Pin.cpu.A8, mode=Pin.IN, pull=Pin.PULL_UP)
        SD_CK: Any  ## <class 'Pin'> = Pin(Pin.cpu.C12, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)
        SD_CMD: Any  ## <class 'Pin'> = Pin(Pin.cpu.D2, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)
        SD_D0: Any  ## <class 'Pin'> = Pin(Pin.cpu.C8, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)
        SD_D1: Any  ## <class 'Pin'> = Pin(Pin.cpu.C9, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)
        SD_D2: Any  ## <class 'Pin'> = Pin(Pin.cpu.C10, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)
        SD_D3: Any  ## <class 'Pin'> = Pin(Pin.cpu.C11, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)
        SD_SW: Any  ## <class 'Pin'> = Pin(Pin.cpu.A8, mode=Pin.IN, pull=Pin.PULL_UP)
        SW: Any  ## <class 'Pin'> = Pin(Pin.cpu.B3, mode=Pin.IN, pull=Pin.PULL_UP)
        USB_DM: Any  ## <class 'Pin'> = Pin(Pin.cpu.A11, mode=Pin.ALT, alt=10)
        USB_DP: Any  ## <class 'Pin'> = Pin(Pin.cpu.A12, mode=Pin.ALT, alt=10)
        USB_ID: Any  ## <class 'Pin'> = Pin(Pin.cpu.A10, mode=Pin.ALT_OPEN_DRAIN, pull=Pin.PULL_UP, alt=10)
        USB_VBUS: Any  ## <class 'Pin'> = Pin(Pin.cpu.A9, mode=Pin.IN)
        X1: Any  ## <class 'Pin'> = Pin(Pin.cpu.A0, mode=Pin.IN)
        X10: Any  ## <class 'Pin'> = Pin(Pin.cpu.B7, mode=Pin.IN)
        X11: Any  ## <class 'Pin'> = Pin(Pin.cpu.C4, mode=Pin.IN)
        X12: Any  ## <class 'Pin'> = Pin(Pin.cpu.C5, mode=Pin.IN)
        X17: Any  ## <class 'Pin'> = Pin(Pin.cpu.B3, mode=Pin.IN, pull=Pin.PULL_UP)
        X18: Any  ## <class 'Pin'> = Pin(Pin.cpu.C13, mode=Pin.IN)
        X19: Any  ## <class 'Pin'> = Pin(Pin.cpu.C0, mode=Pin.IN)
        X2: Any  ## <class 'Pin'> = Pin(Pin.cpu.A1, mode=Pin.IN)
        X20: Any  ## <class 'Pin'> = Pin(Pin.cpu.C1, mode=Pin.IN)
        X21: Any  ## <class 'Pin'> = Pin(Pin.cpu.C2, mode=Pin.IN)
        X22: Any  ## <class 'Pin'> = Pin(Pin.cpu.C3, mode=Pin.IN)
        X3: Any  ## <class 'Pin'> = Pin(Pin.cpu.A2, mode=Pin.IN)
        X4: Any  ## <class 'Pin'> = Pin(Pin.cpu.A3, mode=Pin.IN)
        X5: Any  ## <class 'Pin'> = Pin(Pin.cpu.A4, mode=Pin.IN)
        X6: Any  ## <class 'Pin'> = Pin(Pin.cpu.A5, mode=Pin.IN)
        X7: Any  ## <class 'Pin'> = Pin(Pin.cpu.A6, mode=Pin.IN)
        X8: Any  ## <class 'Pin'> = Pin(Pin.cpu.A7, mode=Pin.IN)
        X9: Any  ## <class 'Pin'> = Pin(Pin.cpu.B6, mode=Pin.IN)
        Y1: Any  ## <class 'Pin'> = Pin(Pin.cpu.C6, mode=Pin.IN)
        Y10: Any  ## <class 'Pin'> = Pin(Pin.cpu.B11, mode=Pin.IN)
        Y11: Any  ## <class 'Pin'> = Pin(Pin.cpu.B0, mode=Pin.IN)
        Y12: Any  ## <class 'Pin'> = Pin(Pin.cpu.B1, mode=Pin.IN)
        Y2: Any  ## <class 'Pin'> = Pin(Pin.cpu.C7, mode=Pin.IN)
        Y3: Any  ## <class 'Pin'> = Pin(Pin.cpu.B8, mode=Pin.IN)
        Y4: Any  ## <class 'Pin'> = Pin(Pin.cpu.B9, mode=Pin.IN)
        Y5: Any  ## <class 'Pin'> = Pin(Pin.cpu.B12, mode=Pin.IN)
        Y6: Any  ## <class 'Pin'> = Pin(Pin.cpu.B13, mode=Pin.IN)
        Y7: Any  ## <class 'Pin'> = Pin(Pin.cpu.B14, mode=Pin.IN)
        Y8: Any  ## <class 'Pin'> = Pin(Pin.cpu.B15, mode=Pin.IN)
        Y9: Any  ## <class 'Pin'> = Pin(Pin.cpu.B10, mode=Pin.IN)

    class cpu:
        """"""

        def __init__(self, *argv, **kwargs) -> None:
            """"""
            ...

        A0: Any  ## <class 'Pin'> = Pin(Pin.cpu.A0, mode=Pin.IN)
        A1: Any  ## <class 'Pin'> = Pin(Pin.cpu.A1, mode=Pin.IN)
        A10: Any  ## <class 'Pin'> = Pin(Pin.cpu.A10, mode=Pin.ALT_OPEN_DRAIN, pull=Pin.PULL_UP, alt=10)
        A11: Any  ## <class 'Pin'> = Pin(Pin.cpu.A11, mode=Pin.ALT, alt=10)
        A12: Any  ## <class 'Pin'> = Pin(Pin.cpu.A12, mode=Pin.ALT, alt=10)
        A13: Any  ## <class 'Pin'> = Pin(Pin.cpu.A13, mode=Pin.OUT)
        A14: Any  ## <class 'Pin'> = Pin(Pin.cpu.A14, mode=Pin.OUT)
        A15: Any  ## <class 'Pin'> = Pin(Pin.cpu.A15, mode=Pin.OUT)
        A2: Any  ## <class 'Pin'> = Pin(Pin.cpu.A2, mode=Pin.IN)
        A3: Any  ## <class 'Pin'> = Pin(Pin.cpu.A3, mode=Pin.IN)
        A4: Any  ## <class 'Pin'> = Pin(Pin.cpu.A4, mode=Pin.IN)
        A5: Any  ## <class 'Pin'> = Pin(Pin.cpu.A5, mode=Pin.IN)
        A6: Any  ## <class 'Pin'> = Pin(Pin.cpu.A6, mode=Pin.IN)
        A7: Any  ## <class 'Pin'> = Pin(Pin.cpu.A7, mode=Pin.IN)
        A8: Any  ## <class 'Pin'> = Pin(Pin.cpu.A8, mode=Pin.IN, pull=Pin.PULL_UP)
        A9: Any  ## <class 'Pin'> = Pin(Pin.cpu.A9, mode=Pin.IN)
        B0: Any  ## <class 'Pin'> = Pin(Pin.cpu.B0, mode=Pin.IN)
        B1: Any  ## <class 'Pin'> = Pin(Pin.cpu.B1, mode=Pin.IN)
        B10: Any  ## <class 'Pin'> = Pin(Pin.cpu.B10, mode=Pin.IN)
        B11: Any  ## <class 'Pin'> = Pin(Pin.cpu.B11, mode=Pin.IN)
        B12: Any  ## <class 'Pin'> = Pin(Pin.cpu.B12, mode=Pin.IN)
        B13: Any  ## <class 'Pin'> = Pin(Pin.cpu.B13, mode=Pin.IN)
        B14: Any  ## <class 'Pin'> = Pin(Pin.cpu.B14, mode=Pin.IN)
        B15: Any  ## <class 'Pin'> = Pin(Pin.cpu.B15, mode=Pin.IN)
        B2: Any  ## <class 'Pin'> = Pin(Pin.cpu.B2, mode=Pin.IN)
        B3: Any  ## <class 'Pin'> = Pin(Pin.cpu.B3, mode=Pin.IN, pull=Pin.PULL_UP)
        B4: Any  ## <class 'Pin'> = Pin(Pin.cpu.B4, mode=Pin.OUT)
        B5: Any  ## <class 'Pin'> = Pin(Pin.cpu.B5, mode=Pin.OUT)
        B6: Any  ## <class 'Pin'> = Pin(Pin.cpu.B6, mode=Pin.IN)
        B7: Any  ## <class 'Pin'> = Pin(Pin.cpu.B7, mode=Pin.IN)
        B8: Any  ## <class 'Pin'> = Pin(Pin.cpu.B8, mode=Pin.IN)
        B9: Any  ## <class 'Pin'> = Pin(Pin.cpu.B9, mode=Pin.IN)
        C0: Any  ## <class 'Pin'> = Pin(Pin.cpu.C0, mode=Pin.IN)
        C1: Any  ## <class 'Pin'> = Pin(Pin.cpu.C1, mode=Pin.IN)
        C10: Any  ## <class 'Pin'> = Pin(Pin.cpu.C10, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)
        C11: Any  ## <class 'Pin'> = Pin(Pin.cpu.C11, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)
        C12: Any  ## <class 'Pin'> = Pin(Pin.cpu.C12, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)
        C13: Any  ## <class 'Pin'> = Pin(Pin.cpu.C13, mode=Pin.IN)
        C2: Any  ## <class 'Pin'> = Pin(Pin.cpu.C2, mode=Pin.IN)
        C3: Any  ## <class 'Pin'> = Pin(Pin.cpu.C3, mode=Pin.IN)
        C4: Any  ## <class 'Pin'> = Pin(Pin.cpu.C4, mode=Pin.IN)
        C5: Any  ## <class 'Pin'> = Pin(Pin.cpu.C5, mode=Pin.IN)
        C6: Any  ## <class 'Pin'> = Pin(Pin.cpu.C6, mode=Pin.IN)
        C7: Any  ## <class 'Pin'> = Pin(Pin.cpu.C7, mode=Pin.IN)
        C8: Any  ## <class 'Pin'> = Pin(Pin.cpu.C8, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)
        C9: Any  ## <class 'Pin'> = Pin(Pin.cpu.C9, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)
        D2: Any  ## <class 'Pin'> = Pin(Pin.cpu.D2, mode=Pin.ALT, pull=Pin.PULL_UP, alt=12)

    @classmethod
    def debug(cls, *args, **kwargs) -> Any:
        ...

    def gpio(self, *args, **kwargs) -> Any:
        ...

    def high(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def irq(self, *args, **kwargs) -> Any:
        ...

    def low(self, *args, **kwargs) -> Any:
        ...

    @classmethod
    def mapper(cls, *args, **kwargs) -> Any:
        ...

    def mode(self, *args, **kwargs) -> Any:
        ...

    def name(self, *args, **kwargs) -> Any:
        ...

    def names(self, *args, **kwargs) -> Any:
        ...

    def off(self, *args, **kwargs) -> Any:
        ...

    def on(self, *args, **kwargs) -> Any:
        ...

    def pin(self, *args, **kwargs) -> Any:
        ...

    def port(self, *args, **kwargs) -> Any:
        ...

    def pull(self, *args, **kwargs) -> Any:
        ...


SOFT_RESET = 0  # type: int


class SPI:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def read(self, *args, **kwargs) -> Any:
        ...

    def readinto(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    LSB = 128  # type: int
    MSB = 0  # type: int

    def deinit(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def write_readinto(self, *args, **kwargs) -> Any:
        ...


class Signal:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def value(self, *args, **kwargs) -> Any:
        ...

    def off(self, *args, **kwargs) -> Any:
        ...

    def on(self, *args, **kwargs) -> Any:
        ...


class SoftI2C:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def readinto(self, *args, **kwargs) -> Any:
        ...

    def start(self, *args, **kwargs) -> Any:
        ...

    def stop(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def readfrom(self, *args, **kwargs) -> Any:
        ...

    def readfrom_into(self, *args, **kwargs) -> Any:
        ...

    def readfrom_mem(self, *args, **kwargs) -> Any:
        ...

    def readfrom_mem_into(self, *args, **kwargs) -> Any:
        ...

    def scan(self, *args, **kwargs) -> Any:
        ...

    def writeto(self, *args, **kwargs) -> Any:
        ...

    def writeto_mem(self, *args, **kwargs) -> Any:
        ...

    def writevto(self, *args, **kwargs) -> Any:
        ...


class SoftSPI:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def read(self, *args, **kwargs) -> Any:
        ...

    def readinto(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    LSB = 128  # type: int
    MSB = 0  # type: int

    def deinit(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def write_readinto(self, *args, **kwargs) -> Any:
        ...


class Timer:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    ONE_SHOT = 1  # type: int
    PERIODIC = 2  # type: int

    def deinit(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...


class UART:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def any(self, *args, **kwargs) -> Any:
        ...

    def read(self, *args, **kwargs) -> Any:
        ...

    def readinto(self, *args, **kwargs) -> Any:
        ...

    def readline(self, *args, **kwargs) -> Any:
        ...

    def write(self, *args, **kwargs) -> Any:
        ...

    CTS = 512  # type: int
    IRQ_RXIDLE = 16  # type: int
    RTS = 256  # type: int

    def deinit(self, *args, **kwargs) -> Any:
        ...

    def init(self, *args, **kwargs) -> Any:
        ...

    def irq(self, *args, **kwargs) -> Any:
        ...

    def readchar(self, *args, **kwargs) -> Any:
        ...

    def sendbreak(self, *args, **kwargs) -> Any:
        ...

    def writechar(self, *args, **kwargs) -> Any:
        ...


class WDT:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def feed(self, *args, **kwargs) -> Any:
        ...


WDT_RESET = 3  # type: int


def bitstream(*args, **kwargs) -> Any:
    ...


def bootloader(*args, **kwargs) -> Any:
    ...


def deepsleep(*args, **kwargs) -> Any:
    ...


def disable_irq(*args, **kwargs) -> Any:
    ...


def enable_irq(*args, **kwargs) -> Any:
    ...


def freq(*args, **kwargs) -> Any:
    ...


def idle(*args, **kwargs) -> Any:
    ...


def info(*args, **kwargs) -> Any:
    ...


def lightsleep(*args, **kwargs) -> Any:
    ...


mem16: Any  ## <class 'mem'> = <16-bit memory>
mem32: Any  ## <class 'mem'> = <32-bit memory>
mem8: Any  ## <class 'mem'> = <8-bit memory>


def reset(*args, **kwargs) -> Any:
    ...


def reset_cause(*args, **kwargs) -> Any:
    ...


def rng(*args, **kwargs) -> Any:
    ...


def sleep(*args, **kwargs) -> Any:
    ...


def soft_reset(*args, **kwargs) -> Any:
    ...


def time_pulse_us(*args, **kwargs) -> Any:
    ...


def unique_id(*args, **kwargs) -> Any:
    ...



import re

# In Pycopy's ure, "." matches newline by default, effectively
# as if DOTALL flag was used.


def compile(pattern, flags=0):
    return re.compile(pattern, flags | re.DOTALL)


def match(pattern, string):
    return re.match(pattern, string, re.DOTALL)


def search(pattern, string):
    return re.search(pattern, string, re.DOTALL)


def sub(pattern, repl, string, count=0, flags=0):
    return re.sub(pattern, repl, string, count, flags | re.DOTALL)



def const(x):
    return x


def native(x):
    return x


def viper(x):
    return x


# Override standard CPython modules/builtins with Pycopy semantics.

import builtins

import uio

builtins.open = uio.open


import gc


def mem_free():
    return 1000000


def mem_alloc():
    return 1000000


gc.mem_free = mem_free
gc.mem_alloc = mem_alloc


import pycopy_imphook



"""
Module: 'platform' on micropython-v1.19.1-stm32
"""
# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'stm32', 'port': 'stm32', 'machine': 'PYBv1.1 with STM32F405RG', 'release': '1.19.1', 'nodename': 'pyboard', 'name': 'micropython', 'family': 'micropython', 'sysname': 'pyboard', 'version': '1.19.1'}
# Stubber: 1.5.6
from typing import Any


def libc_ver(*args, **kwargs) -> Any:
    ...


def platform(*args, **kwargs) -> Any:
    ...


def python_compiler(*args, **kwargs) -> Any:
    ...



from collections.abc import Generator
from typing import Any

POLLIN: Any
POLLOUT: Any

class poll:
    sel: Any
    def __init__(self) -> None: ...
    def register(self, stream, events, userdata: Any | None = ...): ...
    def ipoll(self, timeout: int = ...) -> Generator[Any, None, None]: ...



import selectors


POLLIN = selectors.EVENT_READ
POLLOUT = selectors.EVENT_WRITE


class poll:
    def __init__(self):
        self.sel = selectors.DefaultSelector()

    def register(self, stream, events, userdata=None):
        try:
            self.sel.register(stream, events, userdata)
            return True
        except KeyError:
            self.sel.modify(stream, events, userdata)
            return False

    def ipoll(self, timeout=-1):
        if timeout == -1:
            timeout = None
        else:
            timeout /= 1000
        for key, events in self.sel.select(timeout):
            yield (key.fileobj, events, key.data)



import importlib
from typing import Any

_import_hook: Any
_import_exts: Any

class ImphookFileLoader(importlib._bootstrap_external.FileLoader):
    def create_module(self, spec): ...
    def exec_module(self, mod) -> None: ...

def setimphook(hook, exts): ...



"""
Module: 'os' on micropython-v1.19.1-stm32
"""
# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'stm32', 'port': 'stm32', 'machine': 'PYBv1.1 with STM32F405RG', 'release': '1.19.1', 'nodename': 'pyboard', 'name': 'micropython', 'family': 'micropython', 'sysname': 'pyboard', 'version': '1.19.1'}
# Stubber: 1.5.6
from typing import Any


def remove(*args, **kwargs) -> Any:
    ...


sep = "/"  # type: str


class VfsFat:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def open(self, *args, **kwargs) -> Any:
        ...

    def remove(self, *args, **kwargs) -> Any:
        ...

    def chdir(self, *args, **kwargs) -> Any:
        ...

    def getcwd(self, *args, **kwargs) -> Any:
        ...

    def ilistdir(self, *args, **kwargs) -> Any:
        ...

    def mkdir(self, *args, **kwargs) -> Any:
        ...

    def mkfs(self, *args, **kwargs) -> Any:
        ...

    def mount(self, *args, **kwargs) -> Any:
        ...

    def rename(self, *args, **kwargs) -> Any:
        ...

    def rmdir(self, *args, **kwargs) -> Any:
        ...

    def stat(self, *args, **kwargs) -> Any:
        ...

    def statvfs(self, *args, **kwargs) -> Any:
        ...

    def umount(self, *args, **kwargs) -> Any:
        ...


class VfsLfs2:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def open(self, *args, **kwargs) -> Any:
        ...

    def remove(self, *args, **kwargs) -> Any:
        ...

    def chdir(self, *args, **kwargs) -> Any:
        ...

    def getcwd(self, *args, **kwargs) -> Any:
        ...

    def ilistdir(self, *args, **kwargs) -> Any:
        ...

    def mkdir(self, *args, **kwargs) -> Any:
        ...

    def mkfs(self, *args, **kwargs) -> Any:
        ...

    def mount(self, *args, **kwargs) -> Any:
        ...

    def rename(self, *args, **kwargs) -> Any:
        ...

    def rmdir(self, *args, **kwargs) -> Any:
        ...

    def stat(self, *args, **kwargs) -> Any:
        ...

    def statvfs(self, *args, **kwargs) -> Any:
        ...

    def umount(self, *args, **kwargs) -> Any:
        ...


def chdir(*args, **kwargs) -> Any:
    ...


def dupterm(*args, **kwargs) -> Any:
    ...


def getcwd(*args, **kwargs) -> Any:
    ...


def ilistdir(*args, **kwargs) -> Any:
    ...


def listdir(*args, **kwargs) -> Any:
    ...


def mkdir(*args, **kwargs) -> Any:
    ...


def mount(*args, **kwargs) -> Any:
    ...


def rename(*args, **kwargs) -> Any:
    ...


def rmdir(*args, **kwargs) -> Any:
    ...


def stat(*args, **kwargs) -> Any:
    ...


def statvfs(*args, **kwargs) -> Any:
    ...


def sync(*args, **kwargs) -> Any:
    ...


def umount(*args, **kwargs) -> Any:
    ...


def uname(*args, **kwargs) -> Any:
    ...


def unlink(*args, **kwargs) -> Any:
    ...


def urandom(*args, **kwargs) -> Any:
    ...



import micropython
import json
from json import dump, dumps
import io
import sys


# Before CPython3.6. only str input was acceptet by json module
_json_only_str = sys.version_info < (3, 6)


def load(stream):
    if _json_only_str:
        # io.TextIOWrapper doesn't support text streams as input,
        # so we should pass only binary streams to it.
        if not isinstance(stream, (io.TextIOWrapper, io.StringIO)):
            stream = io.TextIOWrapper(stream)
    return json.load(stream)


def loads(s):
    if _json_only_str and not isinstance(s, str):
        s = s.decode()
    return json.loads(s)



import micropython
from zlib import *


class DecompIO:
    def __init__(self, stream, dict_bits, dictbuf=None):
        self.stream = stream
        self.decomp = decompressobj(dict_bits)
        self.pending = b""

    def read(self, size):
        while len(self.pending) < size:
            inp = self.stream.read(256)
            if not inp:
                break
            outp = self.decomp.decompress(inp)
            self.pending += outp

        outp = self.pending[:size]
        self.pending = self.pending[size:]
        return outp



import time as _time


MICROPY_PY_UTIME_TICKS_PERIOD = 2**30

_PASSTHRU = ("time", "sleep", "localtime")

for f in _PASSTHRU:
    globals()[f] = getattr(_time, f)

clock = _time.process_time()


def sleep_ms(t):
    _time.sleep(t / 1000)


def sleep_us(t):
    _time.sleep(t / 1000000)


def ticks_ms():
    return int(_time.time() * 1000) & (MICROPY_PY_UTIME_TICKS_PERIOD - 1)


def ticks_us():
    return int(_time.time() * 1000000) & (MICROPY_PY_UTIME_TICKS_PERIOD - 1)


ticks_cpu = ticks_us


def ticks_add(t, delta):
    return (t + delta) & (MICROPY_PY_UTIME_TICKS_PERIOD - 1)


def ticks_diff(a, b):
    return ((a - b + MICROPY_PY_UTIME_TICKS_PERIOD // 2) & (MICROPY_PY_UTIME_TICKS_PERIOD - 1)) - MICROPY_PY_UTIME_TICKS_PERIOD // 2


del f



EACCES: int
EADDRINUSE: int
EAGAIN: int
EALREADY: int
EBADF: int
ECONNABORTED: int
ECONNREFUSED: int
ECONNRESET: int
EEXIST: int
EHOSTUNREACH: int
EINPROGRESS: int
EINVAL: int
EIO: int
EISDIR: int
ENOBUFS: int
ENODEV: int
ENOENT: int
ENOMEM: int
ENOTCONN: int
EOPNOTSUPP: int
EPERM: int
ETIMEDOUT: int
errorcode: dict



from typing import Any

PORTRAIT: Any
LANDSCAPE: Any
PORTRAIT_UPSIDEDOWN: Any
LANDSCAPE_UPSIDEDOWN: Any
STARTUP_DECO_NONE: Any
STARTUP_DECO_MLOGO: Any
STARTUP_DECO_INFO: Any
_uart_baud_table: Any

class LCD160CR:
    pwr: Any
    i2c: Any
    spi: Any
    i2c_addr: Any
    buf16: Any
    buf19: Any
    buf: Any
    buf1: Any
    array4: Any
    def __init__(
        self, connect: Any | None = ..., *, pwr: Any | None = ..., i2c: Any | None = ..., spi: Any | None = ..., i2c_addr: int = ...
    ) -> None: ...
    def _send(self, cmd) -> None: ...
    def _fcmd2(self, fmt, a0, a1: int = ..., a2: int = ...) -> None: ...
    def _fcmd2b(self, fmt, a0, a1, a2, a3, a4: int = ...) -> None: ...
    def _waitfor(self, n, buf) -> None: ...
    def oflush(self, n: int = ...) -> None: ...
    def iflush(self) -> None: ...
    @staticmethod
    def rgb(r, g, b): ...
    @staticmethod
    def clip_line(c, w, h): ...
    def set_power(self, on) -> None: ...
    w: Any
    h: Any
    def set_orient(self, orient) -> None: ...
    def set_brightness(self, value) -> None: ...
    def set_i2c_addr(self, addr) -> None: ...
    def set_uart_baudrate(self, baudrate) -> None: ...
    def set_startup_deco(self, value) -> None: ...
    def save_to_flash(self) -> None: ...
    def set_pixel(self, x, y, c) -> None: ...
    def get_pixel(self, x, y): ...
    def get_line(self, x, y, buf) -> None: ...
    def screen_dump(self, buf, x: int = ..., y: int = ..., w: Any | None = ..., h: Any | None = ...) -> None: ...
    def screen_load(self, buf) -> None: ...
    def set_pos(self, x, y) -> None: ...
    def set_text_color(self, fg, bg) -> None: ...
    def set_font(self, font, scale: int = ..., bold: int = ..., trans: int = ..., scroll: int = ...) -> None: ...
    def write(self, s) -> None: ...
    def set_pen(self, line, fill) -> None: ...
    def erase(self) -> None: ...
    def dot(self, x, y) -> None: ...
    def rect(self, x, y, w, h, cmd: int = ...) -> None: ...
    def rect_outline(self, x, y, w, h) -> None: ...
    def rect_interior(self, x, y, w, h) -> None: ...
    def line(self, x1, y1, x2, y2) -> None: ...
    def dot_no_clip(self, x, y) -> None: ...
    def rect_no_clip(self, x, y, w, h) -> None: ...
    def rect_outline_no_clip(self, x, y, w, h) -> None: ...
    def rect_interior_no_clip(self, x, y, w, h) -> None: ...
    def line_no_clip(self, x1, y1, x2, y2) -> None: ...
    def poly_dot(self, data) -> None: ...
    def poly_line(self, data) -> None: ...
    def touch_config(self, calib: bool = ..., save: bool = ..., irq: Any | None = ...) -> None: ...
    def is_touched(self): ...
    def get_touch(self): ...
    def set_spi_win(self, x, y, w, h) -> None: ...
    def fast_spi(self, flush: bool = ...): ...
    def show_framebuf(self, buf) -> None: ...
    def set_scroll(self, on) -> None: ...
    def set_scroll_win(
        self, win, x: int = ..., y: int = ..., w: int = ..., h: int = ..., vec: int = ..., pat: int = ..., fill: int = ..., color: int = ...
    ) -> None: ...
    def set_scroll_win_param(self, win, param, value) -> None: ...
    def set_scroll_buf(self, s) -> None: ...
    def jpeg_start(self, l) -> None: ...
    def jpeg_data(self, buf) -> None: ...
    def jpeg(self, buf) -> None: ...
    def feed_wdt(self) -> None: ...
    def reset(self) -> None: ...



from typing import Any

MICROPY_PY_UTIME_TICKS_PERIOD: Any
_PASSTHRU: Any
clock: Any

def sleep_ms(t) -> None: ...
def sleep_us(t) -> None: ...
def ticks_ms(): ...
def ticks_us(): ...

ticks_cpu = ticks_us

def ticks_add(t, delta): ...
def ticks_diff(a, b): ...



import sys
import warnings

import importlib


_import_hook = None
_import_exts = []


class ImphookFileLoader(importlib._bootstrap_external.FileLoader):
    def create_module(self, spec):
        global _import_hook
        # print("create_module", spec)
        basename = spec.origin.rsplit(".", 1)[0]
        m = _import_hook(spec.name, basename)
        return m

    def exec_module(self, mod):
        # Module is fully populated in create_module
        pass


def setimphook(hook, exts):
    global _import_hook
    old_hook = _import_hook
    _import_hook = hook
    _import_exts.extend(exts)

    for i, el in enumerate(sys.path_hooks):
        if not isinstance(el, type):
            # Assume it's a type wrapped in a closure,
            # as is the case for FileFinder.
            el = type(el("."))
        if el is importlib._bootstrap_external.FileFinder:
            sys.path_hooks.pop(i)
            insert_pos = i
            break
    else:
        warnings.warn("Could not find existing FileFinder to replace, installing ours as the first to use")
        insert_pos = 0

    # Mirrors what's done by importlib._bootstrap_external._install(importlib._bootstrap)
    loaders = [(ImphookFileLoader, _import_exts)] + importlib._bootstrap_external._get_supported_file_loaders()
    # path_hook closure captures supported_loaders in itself, all instances
    # of FileFinder class will be created with it.
    sys.path_hooks.insert(insert_pos, importlib._bootstrap_external.FileFinder.path_hook(*loaders))
    sys.path_importer_cache.clear()
    return old_hook


sys.setimphook = setimphook



from typing import Any

def remove(*args, **kwargs) -> Any: ...

sep: str

class VfsFat:
    def __init__(self, *argv, **kwargs) -> None: ...
    def open(self, *args, **kwargs) -> Any: ...
    def remove(self, *args, **kwargs) -> Any: ...
    def chdir(self, *args, **kwargs) -> Any: ...
    def getcwd(self, *args, **kwargs) -> Any: ...
    def ilistdir(self, *args, **kwargs) -> Any: ...
    def mkdir(self, *args, **kwargs) -> Any: ...
    def mkfs(self, *args, **kwargs) -> Any: ...
    def mount(self, *args, **kwargs) -> Any: ...
    def rename(self, *args, **kwargs) -> Any: ...
    def rmdir(self, *args, **kwargs) -> Any: ...
    def stat(self, *args, **kwargs) -> Any: ...
    def statvfs(self, *args, **kwargs) -> Any: ...
    def umount(self, *args, **kwargs) -> Any: ...

class VfsLfs2:
    def __init__(self, *argv, **kwargs) -> None: ...
    def open(self, *args, **kwargs) -> Any: ...
    def remove(self, *args, **kwargs) -> Any: ...
    def chdir(self, *args, **kwargs) -> Any: ...
    def getcwd(self, *args, **kwargs) -> Any: ...
    def ilistdir(self, *args, **kwargs) -> Any: ...
    def mkdir(self, *args, **kwargs) -> Any: ...
    def mkfs(self, *args, **kwargs) -> Any: ...
    def mount(self, *args, **kwargs) -> Any: ...
    def rename(self, *args, **kwargs) -> Any: ...
    def rmdir(self, *args, **kwargs) -> Any: ...
    def stat(self, *args, **kwargs) -> Any: ...
    def statvfs(self, *args, **kwargs) -> Any: ...
    def umount(self, *args, **kwargs) -> Any: ...

def chdir(*args, **kwargs) -> Any: ...
def dupterm(*args, **kwargs) -> Any: ...
def getcwd(*args, **kwargs) -> Any: ...
def ilistdir(*args, **kwargs) -> Any: ...
def listdir(*args, **kwargs) -> Any: ...
def mkdir(*args, **kwargs) -> Any: ...
def mount(*args, **kwargs) -> Any: ...
def rename(*args, **kwargs) -> Any: ...
def rmdir(*args, **kwargs) -> Any: ...
def stat(*args, **kwargs) -> Any: ...
def statvfs(*args, **kwargs) -> Any: ...
def sync(*args, **kwargs) -> Any: ...
def umount(*args, **kwargs) -> Any: ...
def uname(*args, **kwargs) -> Any: ...
def unlink(*args, **kwargs) -> Any: ...
def urandom(*args, **kwargs) -> Any: ...



import hashlib


class _hash:
    def __init__(self, data=None):
        cls = getattr(hashlib, self.__class__.__name__)
        if data is None:
            self._ = cls()
        else:
            self._ = cls(data)

    def update(self, data):
        self._.update(data)

    def digest(self):
        return self._.digest()


class md5(_hash):
    pass


class sha1(_hash):
    pass


class sha256(_hash):
    pass



"""
Module: 'logging' on micropython-v1.19.1-stm32
"""
# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'stm32', 'port': 'stm32', 'machine': 'PYBv1.1 with STM32F405RG', 'release': '1.19.1', 'nodename': 'pyboard', 'name': 'micropython', 'family': 'micropython', 'sysname': 'pyboard', 'version': '1.19.1'}
# Stubber: 1.5.6
from typing import Any


def debug(*args, **kwargs) -> Any:
    ...


def info(*args, **kwargs) -> Any:
    ...


def getLogger(*args, **kwargs) -> Any:
    ...


def basicConfig(*args, **kwargs) -> Any:
    ...


INFO = 20  # type: int
CRITICAL = 50  # type: int
ERROR = 40  # type: int
WARNING = 30  # type: int
DEBUG = 10  # type: int
NOTSET = 0  # type: int


class Logger:
    """"""

    def __init__(self, *argv, **kwargs) -> None:
        """"""
        ...

    def debug(self, *args, **kwargs) -> Any:
        ...

    def info(self, *args, **kwargs) -> Any:
        ...

    def log(self, *args, **kwargs) -> Any:
        ...

    def exception(self, *args, **kwargs) -> Any:
        ...

    def error(self, *args, **kwargs) -> Any:
        ...

    def warning(self, *args, **kwargs) -> Any:
        ...

    level = 0  # type: int

    def setLevel(self, *args, **kwargs) -> Any:
        ...

    def isEnabledFor(self, *args, **kwargs) -> Any:
        ...

    def critical(self, *args, **kwargs) -> Any:
        ...



from collections import OrderedDict as OrderedDict, namedtuple as namedtuple
from typing import Any

class deque:
    maxlen: Any
    flags: Any
    d: Any
    def __init__(self, iterable, maxlen, flags: int = ...) -> None: ...
    def __len__(self): ...
    def append(self, x) -> None: ...
    def popleft(self): ...



import io


class UioStream:
    def __init__(self, s, is_bin):
        self._s = s
        self._is_bin = is_bin

    def write(self, data, off=None, sz=None):
        if self._is_bin and isinstance(data, str):
            data = data.encode()

        if off is not None:
            if sz is None:
                sz = off
                off = 0
            data = memoryview(data)[off : off + sz]

        self._s.write(data)

    def __getattr__(self, attr):
        return getattr(self._s, attr)

    def __iter__(self):
        return self._s.__iter__()

    def __enter__(self):
        return self

    def __exit__(self, *args):
        return self._s.__exit__(*args)


class StringIO(io.StringIO):
    def __iadd__(self, s):
        self.write(s)
        return self


class BytesIO(io.BytesIO):
    def __iadd__(self, s):
        self.write(s)
        return self


def open(name, mode="r", *args, **kw):
    f = io.open(name, mode, *args, **kw)
    return UioStream(f, "b" in mode)



import micropython
import uio
import ssl


_ctx = ssl.create_default_context()


def wrap_socket(*args, **kw):
    s = _ctx.wrap_socket(*args, **kw)
    return uio.UioStream(s.makefile("rwb", buffering=0), is_bin=True)
